function [GP]=PVECTOR(MATNO,PROPS,LNODS,COORD,...
    NDLEG,NEASS,NOPRS,PRESS,NPLOD,LODPT,POINT,GP)
% Compute the effective nodal force
% Input parameters:
%   MATNO: Material index of each element
%   PROPS: Properties of materials
%   LNODS: Element connections
%   COORD: Coordinates of nodes
%   NPLOD: Number of concentrated loads
%   LODPT: Global index of nodes at which concentrated loads are applied
%   POINT: Specified values of concentrated loads
%   NDLEG: Number of loaded edges
%   NEASS: Element index with loaded edge
%   NOPRS: Global node index along loaded edge
%   PRESS: Specified values of distributed loads at nodes
%   GP:    Global effective nodal force
% Output parameters:
%   GP:    Global effective nodal force
% *****************************************
global NDIME NDOFN NNODE NEDGE NODEG NGAUS;

% Add the point loads to global force vector
if NPLOD>0
    for iPLOD=1:NPLOD
        NRT=(LODPT(iPLOD)-1)*NDOFN;
        for iDOFN=1:NDOFN
            NR=NRT+iDOFN;
            GP(NR,1)=GP(NR,1)+POINT(iPLOD,iDOFN);
        end
    end
end

% Total number of local DOF of each element
NEVAB=NNODE*NDOFN;
% Gaussian point and weight coefficients
[POSGP,WEIGP]=GAUSSQU(NGAUS);

% Calculatie equivalent nodal force on the distributed
% loaded edge
for iDLEG=1:NDLEG
    kELEM=NEASS(iDLEG);
    % Material properties
    kMATS=MATNO(kELEM);
    THICK=PROPS(kMATS,3);
    % Determine coordinates of nodes on the edge
    ELCOD=zeros(NODEG,NDIME);
    for iODEG=1:NODEG
        kPOIN=NOPRS(iDLEG,iODEG);
        for iDIME=1:NDIME
            ELCOD(iODEG,iDIME)=COORD(kPOIN,iDIME);
        end
        %ELCOD(iODEG,:)=COORD(kPOIN,:)
    end
    % Determine local nodal load intensity
    EPRES=zeros(NODEG,NDOFN);
    for iODEG=1:NODEG
        for iDOFN=1:NDOFN
            ii=(iODEG-1)*NDOFN+iDOFN;
            EPRES(iODEG,iDOFN)=PRESS(iDLEG,ii);
        end
    end
    % Integration along the loaded edge
    %    P(iODEG)(iDOFN)=integral(N(iODEG)*p(iDOFN)*dS)
    % dS is arc-length
    PE=zeros(NEVAB,1);
    for iGAUS=1:NGAUS
        EXISP=POSGP(iGAUS);
        % Shape functions and its derivatives for 1D
        % line element
        SHAPE=zeros(1,NODEG);
        DSHAP=zeros(1,NODEG);
        [SHAPE,DSHAP]=SHAPFUN(EXISP);
        
        % Coordinates and derivatives of Gauss points
        %  x=sum(Ni*xi) and y=sum(Ni*yi)
        %  dx/dt=sum(dNi/dt*xi), dy/dt=sum(dNi/dt*yi)
        CORGS=zeros(1,NDIME);
        DERGS=zeros(1,NDIME);
        for iDIME=1:NDIME
            for iODEG=1:NODEG
                CORGS(iDIME)=CORGS(iDIME)+...
                    SHAPE(iODEG)*ELCOD(iODEG,iDIME);
                DERGS(iDIME)=DERGS(iDIME)+...
                    DSHAP(iODEG)*ELCOD(iODEG,iDIME);
            end
        end
        % DVOLU=sqrt((dx/dt)^2+(dy/dt)^2)
        DVOLU=sqrt(DERGS(1)^2+DERGS(2)^2);
        
        % Gauss integration factor
        DVOLU=DVOLU*WEIGP(iGAUS);
        if THICK+1~=1
            DVOLU=DVOLU*THICK;
        end
        
        % Load intensity at Gauss point
        %          p=sum(Ni*pi)
        % for potential problems, PGASH is scalar
        % denoting normal flux
        PGASH=zeros(NDOFN,1);
        for iDOFN=1:NDOFN
            for iODEG=1:NODEG
                PGASH(iDOFN)=PGASH(iDOFN)+...
                    SHAPE(iODEG)*EPRES(iODEG,iDOFN);
            end
        end
        % Compute equivalent nodal load vector PE
        for iNODE=1:NNODE
            kPOIN=LNODS(kELEM,iNODE);
            if kPOIN==NOPRS(iDLEG,1)
                % iNODE is start point of loaded edge
                for iODEG=1:NODEG
                    kNODE=iNODE+iODEG-1;
                    if kNODE>NNODE
                        kNODE=1;
                    end
                    for iDOFN=1:NDOFN
                        iEVAB=(kNODE-1)*NDOFN+iDOFN;
                        PE(iEVAB,1)=PE(iEVAB,1)+...
                            SHAPE(iODEG)*...
                            PGASH(iDOFN)*DVOLU;
                    end
                end
            end
        end
    end
    % Assemble PE into global load term
    for iNODE=1:NNODE
        kPOIN=LNODS(kELEM,iNODE);
        for iDOFN=1:NDOFN
            kEQNS=NDOFN*(kPOIN-1)+iDOFN; % global DOF
            iEVAB=NDOFN*(iNODE-1)+iDOFN; % local DOF
            GP(kEQNS,1)=GP(kEQNS,1)+PE(iEVAB,1);
        end
    end
end
clear ELCOD EPRES PE SHAPE DERIV PGASH POSGP WEIGP;