function [GP]=PVECTOR(MATNO,PROPS,LNODS,COORD,NDLEG,...
    NEASS,NOPRS,PRESS,GP,NINTP,IPCOD,CRBFI)
% Compute effective nodal forces
% Input parameters:
%   MATNO: Material index of each element
%   PROPS: Properties of materials
%   LNODS: Element connections
%   COORD: Coordinates of nodes
%   NPLOD: Number of concentrated loads
%   LODPT: Global index of nodes at which concentrated
%          loads are applied 
%   POINT: Specified values of concentrated loads
%   NDLEG: Number of loaded edges
%   NEASS: Element index with loaded edge
%   NOPRS: Global node index along loaded edge
%   PRESS: Specified values of distributed loads at
%          nodes 
%   GP:    Global effective nodal forces
%   NPOIN: Number of RBF interpolation points
%   IPCOD: Coordinates of interpolation points
%   CRBFI: Coefficient of RBF interpolation
% Output parameters:
%   GP:    Global effective nodal forces
% *****************************************

global NDIME NDOFN NNODE NEDGE NODEG NTYPE NGAUS;

% Material properties
YOUNG=PROPS(1,1);
POISS=PROPS(1,2);
THICK=PROPS(1,3);
TEXPN=PROPS(1,4);
DENST=PROPS(1,5);
if NTYPE==1 %plane stress
    gm=YOUNG*TEXPN/(1-POISS);
elseif NTYPE==2 %plane strain
    gm=YOUNG*TEXPN/(1-2*POISS);
end

NEVAB=NNODE*NDOFN;
% Gaussian point and weight coefficients
[POSGP,WEIGP]=GAUSSQU(NGAUS);

% Calculatie equivalent nodal loads on the distributed loaded edge
for iDLEG=1:NDLEG
    kELEM=NEASS(iDLEG);
    % Determine coordinates of nodes on the element edge
    ELCOD=zeros(NODEG,NDIME);
    for iODEG=1:NODEG
        kPOIN=NOPRS(iDLEG,iODEG);
        for iDIME=1:NDIME
            ELCOD(iODEG,iDIME)=COORD(kPOIN,iDIME);
        end
    end
    % Determine local nodal load intensity
    EPRES=zeros(NODEG,NDOFN);
    for iODEG=1:NODEG
        for iDOFN=1:NDOFN
            ii=(iODEG-1)*NDOFN+iDOFN;
            EPRES(iODEG,iDOFN)=PRESS(iDLEG,ii);
        end
    end
    % Integration along the loaded edge
    %    P(iODEG)(iDOFN)=integral(N(iODEG)*p(iDOFN)*dS)
    % dS is arc-length
    PE=zeros(NEVAB,1);
    for iGAUS=1:NGAUS
        EXISP=POSGP(iGAUS);
        % Shape functions and its derivatives for 1D
        % line element
        SHAPE=zeros(1,NODEG);
        DSHAP=zeros(1,NODEG);
        [SHAPE,DSHAP]=SHAPFUN(EXISP);
        
        % Coordinates and derivatives of Gaussian
        % points
        %  x=sum(Ni*xi) and y=sum(Ni*yi)
        %  dx/dt=sum(dNi/dt*xi)
        %  dy/dt=sum(dNi/dt*yi)
        %  DVOLU=sqrt((dx/dt)^2+(dy/dt)^2)
        CORGS=zeros(1,NDIME);
        DERGS=zeros(1,NDIME);
        for iDIME=1:NDIME
            for iODEG=1:NODEG
                CORGS(iDIME)=CORGS(iDIME)+...
                    SHAPE(iODEG)*ELCOD(iODEG,iDIME);
                DERGS(iDIME)=DERGS(iDIME)+...
                    DSHAP(iODEG)*ELCOD(iODEG,iDIME);
            end
        end
        DVOLU=sqrt(DERGS(1)^2+DERGS(2)^2);
        % Directional cosine at Gaussian point
        %  nx = dy/dS,   ny = - dx/dS
        DS1= DERGS(2)/DVOLU;
        DS2=-DERGS(1)/DVOLU;
        
        % Gaussian integration factor
        DVOLU=DVOLU*WEIGP(iGAUS)*THICK;
        
        % Load intensity at Gaussian point
        %          p=sum(Ni*pi)
        % for plane elastic problems, that is, NDOFN=2, 
        %   PGASH(1) is normal pressure, which is
        %   assumed to be positive if it acts in a
        %   direction into the element
        %   PGASH(2) is tangential load, which is
        %   assumed to be positive if it acts in an
        %   anticlockwise direction with respectt to
        %   the loaded element
        PGASH=zeros(NDOFN,1);
        for iDOFN=1:NDOFN % pn, pt
            for iODEG=1:NODEG
                PGASH(iDOFN)=PGASH(iDOFN)+...
                    SHAPE(iODEG)*EPRES(iODEG,iDOFN);
            end
        end
        %px=-pn*nx-pt*ny
        %py=-pn*ny+pt*nx
        PX=-DS1*PGASH(1)-DS2*PGASH(2); % tx
        PY=-DS2*PGASH(1)+DS1*PGASH(2); % ty
        PGASH(1)=PX;
        PGASH(2)=PY; % PGASH is reset value
        % Modify boundary tractions at Gaussian points
        % th(i)=t(i)-tp(i)+m*T*n(i)
        xp=CORGS(1);
        yp=CORGS(2);
        % particular solution
        [ups,sps]=PARSOLU(xp,yp,NINTP,IPCOD,CRBFI,...
            PROPS);
        % Specified temperature at Gaussian point
        [GBFOR,TEMPR]=USERFUN(xp,yp,PROPS);
        % Evaluate homogeneous tractions
        PGASH(1)=PGASH(1)-(sps(1)*DS1+sps(3)*DS2)+...
            gm*TEMPR*DS1;
        PGASH(2)=PGASH(2)-(sps(3)*DS1+sps(2)*DS2)+...
            gm*TEMPR*DS2;
        % Compute equivalent nodal force vector PE
        for iNODE=1:NNODE
            kPOIN=LNODS(kELEM,iNODE);
            if kPOIN==NOPRS(iDLEG,1)
                % iNODE is start point of loaded edge
                for iODEG=1:NODEG
                    kNODE=iNODE+iODEG-1;
                    if kNODE>NNODE
                        kNODE=1;
                    end
                    for iDOFN=1:NDOFN
                        iEVAB=(kNODE-1)*NDOFN+iDOFN;
                        PE(iEVAB,1)=PE(iEVAB,1)+...
                            SHAPE(iODEG)*...
                            PGASH(iDOFN)*DVOLU;
                    end
                end
            end
        end
    end
    % Assemble PE into global load term
    for iNODE=1:NNODE
        kPOIN=LNODS(kELEM,iNODE);
        for iDOFN=1:NDOFN
            kEQNS=NDOFN*(kPOIN-1)+iDOFN; % global DOF
            iEVAB=NDOFN*(iNODE-1)+iDOFN; % local DOF
            GP(kEQNS,1)=GP(kEQNS,1)+PE(iEVAB,1);
        end
    end
end
clear ELCOD EPRES PE SHAPE DSHAP PGASH POSGP WEIGP;