function [GP]=PVECTOR(LNODS,COORD,NDLEG,NEASS,NOPRS,...
    PRESS,NPLOD,LODPT,POINT,GP)
% Compute effective nodal forces
% Input parameters:
%   MATNO: Material index of each element
%   PROPS: Properties of materials
%   LNODS: Element connections
%   COORD: Coordinates of nodes
%   NPLOD: Number of concentrated loads
%   LODPT: Global index of nodes at which concentrated
%          loads are applied
%   POINT: Specified values of concentrated loads
%   NDLEG: Number of loaded edges
%   NEASS: Element index with loaded edge
%   NOPRS: Global node index along loaded edge
%   PRESS: Specified values of distributed loads at
%          nodes
%   GP:    Global effective nodal loads
% Output parameters:
%   GP:    Global effective nodal loads
% *****************************************
global NDIME NDOFN NNODE NEDGE NODEG NGAUS;

% Add the point loads to global load vector
if NPLOD>0
    for iPLOD=1:NPLOD
        NRT=(LODPT(iPLOD)-1)*NDOFN;
        for iDOFN=1:NDOFN
            NR=NRT+iDOFN;
            GP(NR,1)=GP(NR,1)+POINT(iPLOD,iDOFN);
        end
    end
end

% Total number of local DOF of each element
NEVAB=NNODE*NDOFN;
% Gaussian point and weight coefficients
[POSGP,WEIGP]=GAUSSQU(NGAUS);

% Calculatie equivalent nodal loads on the distributed
% loaded edge
for iDLEG=1:NDLEG
    kELEM=NEASS(iDLEG);
    % Determine coordinates of nodes on the element
    % edge
    ELCOD=zeros(NODEG,NDIME);
    for iODEG=1:NODEG
        kPOIN=NOPRS(iDLEG,iODEG);
        for iDIME=1:NDIME
            ELCOD(iODEG,iDIME)=COORD(kPOIN,iDIME);
        end
        %ELCOD(iODEG,:)=COORD(kPOIN,:)
    end
    % Determine local nodal load intensity
    EPRES=zeros(NODEG,NDOFN);
    for iODEG=1:NODEG
        for iDOFN=1:NDOFN
            ii=(iODEG-1)*NDOFN+iDOFN;
            EPRES(iODEG,iDOFN)=PRESS(iDLEG,ii);
        end
    end
    % Integration along loaded edge
    %    P(iODEG)(iDOFN)=integral(N(iODEG)*p(iDOFN)*dS)
    % dS is arc-length
    PE=zeros(NEVAB,1);
    for iGAUS=1:NGAUS
        EXISP=POSGP(iGAUS);
        % Shape functions and its derivatives for 1D
        % line element
        SHAPE=zeros(1,NODEG);
        DSHAP=zeros(1,NODEG);
        [SHAPE,DSHAP]=SHAPFUN(EXISP);
        
        % Coordinates and derivatives of Gaussian
        % points
        %  x=sum(Ni*xi), y=sum(Ni*yi)
        %  dx/dt=sum(dNi/dt*xi)
        %  dy/dt=sum(dNi/dt*yi)
        %  DVOLU=sqrt((dx/dt)^2+(dy/dt)^2)
        CORGS=zeros(1,NDIME);
        DERGS=zeros(1,NDIME);
        for iDIME=1:NDIME
            for iODEG=1:NODEG
                CORGS(iDIME)=CORGS(iDIME)+...
                    SHAPE(iODEG)*ELCOD(iODEG,iDIME);
                DERGS(iDIME)=DERGS(iDIME)+...
                    DSHAP(iODEG)*ELCOD(iODEG,iDIME);
            end
        end
        DVOLU=sqrt(DERGS(1)^2+DERGS(2)^2);
        % Directional cosine at Gaussian point
        %  nx = dy/dS,   ny = - dx/dS
        DS1= DERGS(2)/DVOLU;
        DS2=-DERGS(1)/DVOLU;
        
        % Gauss integration factor
        DVOLU=DVOLU*WEIGP(iGAUS);
        
        % Load intensity at Gaussian point
        %          p=sum(Ni*pi)
        % for plane elastic problems, that is, NDOFN=2, 
        %   PGASH(1) is normal pressure, which is
        %   assumed to be positive if it acts in a
        %   direction into the element
        %   PGASH(2) is tangential load, which is
        %   assumed to be positive if it acts in an
        %   anticlockwise direction with respectt to
        %   the loaded element
        PGASH=zeros(NDOFN,1);
        for iDOFN=1:NDOFN % pn, pt
            for iODEG=1:NODEG
                PGASH(iDOFN)=PGASH(iDOFN)+...
                    SHAPE(iODEG)*EPRES(iODEG,iDOFN);
            end
        end
        % px=-pn*nx-pt*ny
        % py=-pn*ny+pt*nx
        PX=-DS1*PGASH(1)-DS2*PGASH(2);
        PY=-DS2*PGASH(1)+DS1*PGASH(2);
        PGASH(1)=PX;
        PGASH(2)=PY;
        % PGASH now is reset value
        % Compute equivalent nodal forces PE
        for iNODE=1:NNODE
            kPOIN=LNODS(kELEM,iNODE);
            if kPOIN==NOPRS(iDLEG,1)
                % iNODE is start point of loaded edge
                for iODEG=1:NODEG
                    kNODE=iNODE+iODEG-1;
                    if kNODE>NNODE
                        kNODE=1;
                    end
                    for iDOFN=1:NDOFN
                        iEVAB=(kNODE-1)*NDOFN+iDOFN;
                        PE(iEVAB,1)=PE(iEVAB,1)+...
                            SHAPE(iODEG)*...
                            PGASH(iDOFN)*DVOLU;
                    end
                end
            end
        end
    end
    % Assemble PE into global forces vector GP
    for iNODE=1:NNODE
        kPOIN=LNODS(kELEM,iNODE);
        for iDOFN=1:NDOFN
            kEQNS=NDOFN*(kPOIN-1)+iDOFN; % global DOF
            iEVAB=NDOFN*(iNODE-1)+iDOFN; % local DOF
            GP(kEQNS,1)=GP(kEQNS,1)+PE(iEVAB,1);
        end
    end
end
clear ELCOD EPRES PE SHAPE DSHAP PGASH POSGP WEIGP;